W

Type Alias W 

pub type W = W<CTL1_SPEC>;
Register CTL1 writer

Aliased Type

pub struct W { /* private fields */ }

Implementations

Source

impl W

pub fn ctl1_enable(&mut self) -> CTL1_ENABLE_W<'_, CTL1_SPEC, 0>

Bit 0 - This bit turns on the comparator. When the comparator is turned off it consumes no power.

pub fn ctl1_mode(&mut self) -> CTL1_MODE_W<'_, CTL1_SPEC, 1>

Bit 1 - This bit selects the comparator operating mode.

pub fn ctl1_exch(&mut self) -> CTL1_EXCH_W<'_, CTL1_SPEC, 2>

Bit 2 - This bit exchanges the comparator inputs and inverts the comparator output.

pub fn ctl1_short(&mut self) -> CTL1_SHORT_W<'_, CTL1_SPEC, 3>

Bit 3 - This bit shorts the positive and negative input terminals of the comparator.

pub fn ctl1_ies(&mut self) -> CTL1_IES_W<'_, CTL1_SPEC, 4>

Bit 4 - This bit selected the interrupt edge for COMPIFG and COMPINVIFG.

pub fn ctl1_hyst(&mut self) -> CTL1_HYST_W<'_, CTL1_SPEC, 5>

Bits 5:6 - These bits select the hysteresis setting of the comparator.

pub fn ctl1_outpol(&mut self) -> CTL1_OUTPOL_W<'_, CTL1_SPEC, 7>

Bit 7 - This bit selects the comparator output polarity.

pub fn ctl1_flten(&mut self) -> CTL1_FLTEN_W<'_, CTL1_SPEC, 8>

Bit 8 - This bit enables the analog filter at comparator output.

pub fn ctl1_fltdly(&mut self) -> CTL1_FLTDLY_W<'_, CTL1_SPEC, 9>

Bits 9:10 - These bits select the comparator output filter delay. See the device-specific data sheet for specific values on comparator propagation delay for different filter delay settings.

pub fn ctl1_wincompen(&mut self) -> CTL1_WINCOMPEN_W<'_, CTL1_SPEC, 12>

Bit 12 - This bit enables window comparator operation of comparator.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Safety

Passing incorrect value can cause undefined behaviour. See reference manual