pub type W = W<CTL2_SPEC>;Expand description
Register CTL2 writer
Aliased Type
pub struct W { /* private fields */ }Implementations
Sourceimpl W
impl W
Sourcepub fn ctl2_refmode(&mut self) -> CTL2_REFMODE_W<'_, CTL2_SPEC, 0>
pub fn ctl2_refmode(&mut self) -> CTL2_REFMODE_W<'_, CTL2_SPEC, 0>
Bit 0 - This bit requests ULP_REF bandgap operation in static mode or sampled mode. The local reference buffer and 8-bit DAC inside comparator module are also configured accordingly. Static mode operation offers higher accuracy but consumes higher current. Sampled mode operation consumes lower current but with relaxed reference voltage accuracy. Comparator requests for reference voltage from ULP_REF only when REFLVL > 0.
Sourcepub fn ctl2_refsrc(&mut self) -> CTL2_REFSRC_W<'_, CTL2_SPEC, 3>
pub fn ctl2_refsrc(&mut self) -> CTL2_REFSRC_W<'_, CTL2_SPEC, 3>
Bits 3:4 - These bits select the reference source for the comparator.
Sourcepub fn ctl2_refsel(&mut self) -> CTL2_REFSEL_W<'_, CTL2_SPEC, 7>
pub fn ctl2_refsel(&mut self) -> CTL2_REFSEL_W<'_, CTL2_SPEC, 7>
Bit 7 - This bit selects if the selected reference voltage is applied to positive or negative terminal of the comparator.
Sourcepub fn ctl2_blanksrc(&mut self) -> CTL2_BLANKSRC_W<'_, CTL2_SPEC, 8>
pub fn ctl2_blanksrc(&mut self) -> CTL2_BLANKSRC_W<'_, CTL2_SPEC, 8>
Bits 8:10 - These bits select the blanking source for the comparator.
Sourcepub fn ctl2_dacctl(&mut self) -> CTL2_DACCTL_W<'_, CTL2_SPEC, 16>
pub fn ctl2_dacctl(&mut self) -> CTL2_DACCTL_W<'_, CTL2_SPEC, 16>
Bit 16 - This bit determines if the comparator output or DACSW bit controls the selection between DACCODE0 and DACCODE1.
Sourcepub fn ctl2_dacsw(&mut self) -> CTL2_DACSW_W<'_, CTL2_SPEC, 17>
pub fn ctl2_dacsw(&mut self) -> CTL2_DACSW_W<'_, CTL2_SPEC, 17>
Bit 17 - This bit selects between DACCODE0 and DACCODE1 to 8-bit DAC when DACCTL bit is 1.
Sourcepub fn ctl2_sampmode(&mut self) -> CTL2_SAMPMODE_W<'_, CTL2_SPEC, 24>
pub fn ctl2_sampmode(&mut self) -> CTL2_SAMPMODE_W<'_, CTL2_SPEC, 24>
Bit 24 - Enable sampled mode of comparator.