R

Type Alias R 

pub type R = R<RIS_SPEC>;
Register RIS reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn ris_compifg(&self) -> RIS_COMPIFG_R

Bit 1 - Raw interrupt status for comparator output interrupt flag. The IES bit defines the transition of the comparator output setting this bit.

pub fn ris_compinvifg(&self) -> RIS_COMPINVIFG_R

Bit 2 - Raw interrupt status for comparator output inverted interrupt flag. The IES bit defines the transition of the comparator output setting this bit.

pub fn ris_outrdyifg(&self) -> RIS_OUTRDYIFG_R

Bit 3 - Raw interrupt status for comparator output ready interrupt flag. This bit is set when the comparator output is valid.