pub enum STATCMD_FAILMISC_A {
STATCMD_FAILMISC_STATNOFAIL = 0,
STATCMD_FAILMISC_STATFAIL = 1,
}Expand description
Command failed due to error other than write/erase protect violation or verify error. This is an extra bit in case a new failure mechanism is added which requires a status bit.
Value on reset: 0
Variants