STATCMD_FAILMODE_R

Type Alias STATCMD_FAILMODE_R 

pub type STATCMD_FAILMODE_R = BitReader<STATCMD_FAILMODE_A>;
Field STATCMD_FAILMODE reader - Command failed because a bank has been set to a mode other than READ. Program and Erase commands cannot be initiated unless all banks are in READ mode.

Aliased Type

pub struct STATCMD_FAILMODE_R { /* private fields */ }

Implementations

Source

impl STATCMD_FAILMODE_R

pub const fn variant(&self) -> STATCMD_FAILMODE_A

Get enumerated values variant

pub fn is_statcmd_failmode_statnofail(&self) -> bool

STATNOFAIL

pub fn is_statcmd_failmode_statfail(&self) -> bool

STATFAIL