R

Type Alias R 

pub type R = R<TIMEOUT_CTL_SPEC>;
Register TIMEOUT_CTL reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn timeout_ctl_tcntla(&self) -> TIMEOUT_CTL_TCNTLA_R

Bits 0:7 - Timeout counter A load value Counter A is used for SCL low detection. This field contains the upper 8 bits of a 12-bit pre-load value for the Timeout A count. NOTE: The value of CNTLA must be greater than 1h. Each count is equal to 520 times the timeout period of functional clock. For example, with 8MHz functional clock and a 100KHz operating I2C clock, one timeout period will be equal to (1 / 8MHz) * 520 or 65 us.

pub fn timeout_ctl_tcntaen(&self) -> TIMEOUT_CTL_TCNTAEN_R

Bit 15 - Timeout Counter A Enable

pub fn timeout_ctl_tcntlb(&self) -> TIMEOUT_CTL_TCNTLB_R

Bits 16:23 - Timeout Count B Load: Counter B is used for SCL High Detection. This field contains the upper 8 bits of a 12-bit pre-load value for the Timeout B count. NOTE: The value of CNTLB must be greater than 1h. Each count is equal to 1* clock period. For example, with 10MHz functional clock one timeout period will be equal to1*100ns.

pub fn timeout_ctl_tcntben(&self) -> TIMEOUT_CTL_TCNTBEN_R

Bit 31 - Timeout Counter B Enable