RESETLEVEL_LEVEL_R

Type Alias RESETLEVEL_LEVEL_R 

pub type RESETLEVEL_LEVEL_R = FieldReader<RESETLEVEL_LEVEL_A>;
Field RESETLEVEL_LEVEL reader - LEVEL is used to specify the type of reset to be issued when RESETCMD is set to generate a software triggered reset.

Aliased Type

pub struct RESETLEVEL_LEVEL_R { /* private fields */ }

Implementations

Source

impl RESETLEVEL_LEVEL_R

pub const fn variant(&self) -> Option<RESETLEVEL_LEVEL_A>

Get enumerated values variant

pub fn is_resetlevel_level_cpu(&self) -> bool

CPU

pub fn is_resetlevel_level_boot(&self) -> bool

BOOT

pub fn is_resetlevel_level_bootloaderentry(&self) -> bool

BOOTLOADERENTRY

pub fn is_resetlevel_level_por(&self) -> bool

POR

pub fn is_resetlevel_level_bootloaderexit(&self) -> bool

BOOTLOADEREXIT