RESETLEVEL_LEVEL_W

Type Alias RESETLEVEL_LEVEL_W 

pub type RESETLEVEL_LEVEL_W<'a, REG, const O: u8> = FieldWriter<'a, REG, 3, O, RESETLEVEL_LEVEL_A>;
Field RESETLEVEL_LEVEL writer - LEVEL is used to specify the type of reset to be issued when RESETCMD is set to generate a software triggered reset.

Aliased Type

pub struct RESETLEVEL_LEVEL_W<'a, REG, const O: u8> { /* private fields */ }

Implementations

Source

impl<'a, REG, const O: u8> RESETLEVEL_LEVEL_W<'a, REG, O>
where REG: Writable + RegisterSpec, REG::Ux: From<u8>,

pub fn resetlevel_level_cpu(self) -> &'a mut W<REG>

CPU

pub fn resetlevel_level_boot(self) -> &'a mut W<REG>

BOOT

pub fn resetlevel_level_bootloaderentry(self) -> &'a mut W<REG>

BOOTLOADERENTRY

pub fn resetlevel_level_por(self) -> &'a mut W<REG>

POR

pub fn resetlevel_level_bootloaderexit(self) -> &'a mut W<REG>

BOOTLOADEREXIT