Module sysoscfclctl

Module sysoscfclctl 

SYSOSC frequency correction loop (FCL) ROSC enable

Structs

SYSOSCFCLCTL_SPEC
SYSOSC frequency correction loop (FCL) ROSC enable

Enums

SYSOSCFCLCTL_KEY_AW
The key value of 2Ah (42) must be written to KEY together with SETUSEFCL to enable the FCL.
SYSOSCFCLCTL_SETUSEFCL_AW
Set SETUSEFCL to enable the frequency correction loop in SYSOSC. Once enabled, this state is locked until the next BOOTRST.

Type Aliases

SYSOSCFCLCTL_KEY_W
Field SYSOSCFCLCTL_KEY writer - The key value of 2Ah (42) must be written to KEY together with SETUSEFCL to enable the FCL.
SYSOSCFCLCTL_SETUSEFCL_W
Field SYSOSCFCLCTL_SETUSEFCL writer - Set SETUSEFCL to enable the frequency correction loop in SYSOSC. Once enabled, this state is locked until the next BOOTRST.
W
Register SYSOSCFCLCTL writer