R

Type Alias R 

pub type R = R<DESC_SPEC>;
Register DESC reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn desc_minrev(&self) -> DESC_MINREV_R

Bits 0:3 - Minor rev of the IP

pub fn desc_majrev(&self) -> DESC_MAJREV_R

Bits 4:7 - Major rev of the IP

pub fn desc_instnum(&self) -> DESC_INSTNUM_R

Bits 8:11 - Instance Number within the device. This will be a parameter to the RTL for modules that can have multiple instances

pub fn desc_featurever(&self) -> DESC_FEATUREVER_R

Bits 12:15 - Feature Set for the module instance

pub fn desc_moduleid(&self) -> DESC_MODULEID_R

Bits 16:31 - Module identification contains a unique peripheral identification number. The assignments are maintained in a central database for all of the platform modules to ensure uniqueness.