R

Type Alias R 

pub type R = R<TXDATA_SPEC>;
Register TXDATA reader

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn txdata_data(&self) -> TXDATA_DATA_R

Bits 0:7 - Data Transmitted or Received Data that is to be transmitted via the UART is written to this field. When read, this field contains the data that was received by the UART.