pub type W = W<CTL1_SPEC>;Expand description
Register CTL1 writer
Aliased Type
pub struct W { /* private fields */ }Implementations
Sourceimpl W
impl W
Sourcepub fn ctl1_enable(&mut self) -> CTL1_ENABLE_W<'_, CTL1_SPEC, 0>
pub fn ctl1_enable(&mut self) -> CTL1_ENABLE_W<'_, CTL1_SPEC, 0>
Bit 0 - This bit turns on the comparator. When the comparator is turned off it consumes no power.
Sourcepub fn ctl1_mode(&mut self) -> CTL1_MODE_W<'_, CTL1_SPEC, 1>
pub fn ctl1_mode(&mut self) -> CTL1_MODE_W<'_, CTL1_SPEC, 1>
Bit 1 - This bit selects the comparator operating mode.
Sourcepub fn ctl1_exch(&mut self) -> CTL1_EXCH_W<'_, CTL1_SPEC, 2>
pub fn ctl1_exch(&mut self) -> CTL1_EXCH_W<'_, CTL1_SPEC, 2>
Bit 2 - This bit exchanges the comparator inputs and inverts the comparator output.
Sourcepub fn ctl1_short(&mut self) -> CTL1_SHORT_W<'_, CTL1_SPEC, 3>
pub fn ctl1_short(&mut self) -> CTL1_SHORT_W<'_, CTL1_SPEC, 3>
Bit 3 - This bit shorts the positive and negative input terminals of the comparator.
Sourcepub fn ctl1_ies(&mut self) -> CTL1_IES_W<'_, CTL1_SPEC, 4>
pub fn ctl1_ies(&mut self) -> CTL1_IES_W<'_, CTL1_SPEC, 4>
Bit 4 - This bit selected the interrupt edge for COMPIFG and COMPINVIFG.
Sourcepub fn ctl1_hyst(&mut self) -> CTL1_HYST_W<'_, CTL1_SPEC, 5>
pub fn ctl1_hyst(&mut self) -> CTL1_HYST_W<'_, CTL1_SPEC, 5>
Bits 5:6 - These bits select the hysteresis setting of the comparator.
Sourcepub fn ctl1_outpol(&mut self) -> CTL1_OUTPOL_W<'_, CTL1_SPEC, 7>
pub fn ctl1_outpol(&mut self) -> CTL1_OUTPOL_W<'_, CTL1_SPEC, 7>
Bit 7 - This bit selects the comparator output polarity.
Sourcepub fn ctl1_flten(&mut self) -> CTL1_FLTEN_W<'_, CTL1_SPEC, 8>
pub fn ctl1_flten(&mut self) -> CTL1_FLTEN_W<'_, CTL1_SPEC, 8>
Bit 8 - This bit enables the analog filter at comparator output.
Sourcepub fn ctl1_fltdly(&mut self) -> CTL1_FLTDLY_W<'_, CTL1_SPEC, 9>
pub fn ctl1_fltdly(&mut self) -> CTL1_FLTDLY_W<'_, CTL1_SPEC, 9>
Bits 9:10 - These bits select the comparator output filter delay. See the device-specific data sheet for specific values on comparator propagation delay for different filter delay settings.
Sourcepub fn ctl1_wincompen(&mut self) -> CTL1_WINCOMPEN_W<'_, CTL1_SPEC, 12>
pub fn ctl1_wincompen(&mut self) -> CTL1_WINCOMPEN_W<'_, CTL1_SPEC, 12>
Bit 12 - This bit enables window comparator operation of comparator.