pub type RESETLEVEL_LEVEL_R = FieldReader<RESETLEVEL_LEVEL_A>;Expand description
Field RESETLEVEL_LEVEL reader - LEVEL is used to specify the type of reset to be issued when RESETCMD is set to generate a software triggered reset.
Aliased Type
pub struct RESETLEVEL_LEVEL_R { /* private fields */ }Implementations
Sourceimpl RESETLEVEL_LEVEL_R
impl RESETLEVEL_LEVEL_R
Sourcepub const fn variant(&self) -> Option<RESETLEVEL_LEVEL_A>
pub const fn variant(&self) -> Option<RESETLEVEL_LEVEL_A>
Get enumerated values variant
Sourcepub fn is_resetlevel_level_cpu(&self) -> bool
pub fn is_resetlevel_level_cpu(&self) -> bool
CPU
Sourcepub fn is_resetlevel_level_boot(&self) -> bool
pub fn is_resetlevel_level_boot(&self) -> bool
BOOT
Sourcepub fn is_resetlevel_level_bootloaderentry(&self) -> bool
pub fn is_resetlevel_level_bootloaderentry(&self) -> bool
BOOTLOADERENTRY
Sourcepub fn is_resetlevel_level_por(&self) -> bool
pub fn is_resetlevel_level_por(&self) -> bool
POR
Sourcepub fn is_resetlevel_level_bootloaderexit(&self) -> bool
pub fn is_resetlevel_level_bootloaderexit(&self) -> bool
BOOTLOADEREXIT