pub type RESETLEVEL_LEVEL_W<'a, REG, const O: u8> = FieldWriter<'a, REG, 3, O, RESETLEVEL_LEVEL_A>;Expand description
Field RESETLEVEL_LEVEL writer - LEVEL is used to specify the type of reset to be issued when RESETCMD is set to generate a software triggered reset.
Aliased Type
pub struct RESETLEVEL_LEVEL_W<'a, REG, const O: u8> { /* private fields */ }Implementations
Sourceimpl<'a, REG, const O: u8> RESETLEVEL_LEVEL_W<'a, REG, O>
impl<'a, REG, const O: u8> RESETLEVEL_LEVEL_W<'a, REG, O>
Sourcepub fn resetlevel_level_cpu(self) -> &'a mut W<REG>
pub fn resetlevel_level_cpu(self) -> &'a mut W<REG>
CPU
Sourcepub fn resetlevel_level_boot(self) -> &'a mut W<REG>
pub fn resetlevel_level_boot(self) -> &'a mut W<REG>
BOOT
Sourcepub fn resetlevel_level_bootloaderentry(self) -> &'a mut W<REG>
pub fn resetlevel_level_bootloaderentry(self) -> &'a mut W<REG>
BOOTLOADERENTRY
Sourcepub fn resetlevel_level_por(self) -> &'a mut W<REG>
pub fn resetlevel_level_por(self) -> &'a mut W<REG>
POR
Sourcepub fn resetlevel_level_bootloaderexit(self) -> &'a mut W<REG>
pub fn resetlevel_level_bootloaderexit(self) -> &'a mut W<REG>
BOOTLOADEREXIT