SYSOSC frequency correction loop (FCL) ROSC enable
Structs
- SYSOSCFCLCTL_
SPEC - SYSOSC frequency correction loop (FCL) ROSC enable
Enums
- SYSOSCFCLCTL_
KEY_ AW - The key value of 2Ah (42) must be written to KEY together with SETUSEFCL to enable the FCL.
- SYSOSCFCLCTL_
SETUSEFCL_ AW - Set SETUSEFCL to enable the frequency correction loop in SYSOSC. Once enabled, this state is locked until the next BOOTRST.
Type Aliases
- SYSOSCFCLCTL_
KEY_ W - Field
SYSOSCFCLCTL_KEYwriter - The key value of 2Ah (42) must be written to KEY together with SETUSEFCL to enable the FCL. - SYSOSCFCLCTL_
SETUSEFCL_ W - Field
SYSOSCFCLCTL_SETUSEFCLwriter - Set SETUSEFCL to enable the frequency correction loop in SYSOSC. Once enabled, this state is locked until the next BOOTRST. - W
- Register
SYSOSCFCLCTLwriter