pub type R = R<IFLS_SPEC>;Expand description
Register IFLS reader
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn ifls_txiflsel(&self) -> IFLS_TXIFLSEL_R
pub fn ifls_txiflsel(&self) -> IFLS_TXIFLSEL_R
Bits 0:2 - UART Transmit Interrupt FIFO Level Select The trigger points for the transmit interrupt are as follows: Note: for undefined settings the default configuration is used.
Sourcepub fn ifls_rxiflsel(&self) -> IFLS_RXIFLSEL_R
pub fn ifls_rxiflsel(&self) -> IFLS_RXIFLSEL_R
Bits 4:6 - UART Receive Interrupt FIFO Level Select The trigger points for the receive interrupt are as follows: Note: In ULP domain the trigger levels are used for: 0: LVL_1_4 4: LVL_FULL For undefined settings the default configuration is used.
Sourcepub fn ifls_rxtosel(&self) -> IFLS_RXTOSEL_R
pub fn ifls_rxtosel(&self) -> IFLS_RXTOSEL_R
Bits 8:11 - UART Receive Interrupt Timeout Select. When receiving no start edge for an additional character within the set bittimes a RX interrupt is set even if the FIFO level is not reached. A value of 0 disables this function.